@@ -9,7 +9,7 @@ my $java = new Java();
 #my $obj = $java->create_object("thot.Test","mark");
 #print $obj->get->get_value;
 #exit;
-my $class = $java->java_lang_Class("forName","Test");
+my $class = $java->java_lang_Class("forName","Test2");
 my $constructors = $class->getConstructors();
 #my $v = $constructors->name;
 my $test_obj = $class->newInstance();
@@ -25,3 +25,6 @@ print "GOT: $val2\n";
 my $val4 = $test_obj->get_string->get_value;
 print "GOT: $val4\n";
 
+my $val5 = $test_obj->getPTEST;
+print $val5->next->get_value, "\n";
+
